@@ -7,7 +7,7 @@ use Carp qw(croak);
 use List::Util qw(sum);
 use Statistics::Descriptive;
 use vars qw($VERSION);
-$VERSION = 0.031;
+$VERSION = 0.033;
 
 =pod
 
@@ -17,7 +17,7 @@ Statistics::FisherPitman - Randomization-based alternative to one-way independen
 
 =head1 SYNOPSIS
 
- use Statistics::FisherPitman 0.031;
+ use Statistics::FisherPitman 0.033;
 
  my @dat1 = (qw/12 12 14 15 12 11 15/);
  my @dat2 = (qw/13 14 18 19 22 21 26/);
@@ -212,7 +212,7 @@ sub p_value {
     my ($n_gteq, $name, @ari, @perm, %rands) = (0);
     
     foreach (1 .. $resamplings) {
-        fy_shuffle(\@dat);
+        _fy_shuffle(\@dat);
         @perm = @dat;
         foreach $name(keys %data) {
             @ari = ();
@@ -301,7 +301,7 @@ sub _conf_int {
     return [$lo, $hi];
 }
 
-sub fy_shuffle { # fisher-yates shuffle, via Perl FAQ 4
+sub _fy_shuffle { # fisher-yates shuffle, via Perl FAQ 4
 	my ($list) = @_;
 	my $i;
 	for ($i = @$list; --$i; ) {
@@ -336,7 +336,6 @@ The following shows how the test would be performed with the present module; usi
  require Statistics::FisherPitman;
  my $fishpit = Statistics::FisherPitman->new();
  $fishpit->load_data($data);
- $| = 1; # this could take a little while
  $fishpit->test(resamplings => 10000)->dump(conf_int => 1, precision_p => 3);
  # This prints, e.g.: T = 56062045.0525, p = 0.014 (95% CI: 0.011, 0.016)
 
